#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include "engine/includes/CGame.h"

#define 	CRD_PILE			0
#define 	CRD_FOUNDATION		1
#define 	CRD_RESERVE 	    2
#define		CRD_WASTE   		3
#define 	CRD_VIRTUAL			4

//Joystick procedures
void HandleInput();
void KeyDown(const Uint8& key);
void KeyUp(const Uint8& key);
void MoveCursor();

//Audio procedures
void InitAudio();
int volume;

//Menu
void Menu();
void MenuOptions();
void LoadFont(u8 size);
void drawText(SDL_Surface* screen, char* string, int x, int y, int fR, int fG, int fB);
void drawTextInt(SDL_Surface* screen, int number, int x, int y, int fR, int fG, int fB);

//Menu colors definition
SDL_Color clrFg = {0,46,184};
SDL_Color clrmenu = {46,184,0};
SDL_Color sltmenu = {184,0,46};
SDL_Color optmenu = {0,0,0};

TTF_Font* font;
Mix_Music *music = NULL;
SDL_Surface *screen;
SDL_Joystick *joystick;
Uint32 milliseconds;
CGame Klondike;

//cursor position
int x = 160;
int y = 120;
SDL_Rect rcMouse;

// Joystick states (1=pressed)
int up, down, left, right, upleft, upright, downleft, downright, start;

//Card type distribution (1 or 3 cards in the same time)
bool threeCards = false;

//Card style (0->default (blue) , 1->brown)
int cardStyle = 0;

//Music played or not
bool musicOn = false;

//Number of turns
int turns = 10;

//Cursor choice
int cursorNum = 1;

void Initialize()
{
	//do some initialization and create the regions
	atexit(SDL_Quit);
	
	//Fonts
	TTF_Init();
	atexit(TTF_Quit);
	
	//Video, controls and sound
	SDL_Init(SDL_INIT_JOYSTICK | SDL_INIT_VIDEO | SDL_INIT_AUDIO);
	screen = SDL_SetVideoMode(320, 240, 16, SDL_SWSURFACE | SDL_HWPALETTE | SDL_FULLSCREEN);
	
	//Controls
	SDL_ShowCursor (0);
	joystick = SDL_JoystickOpen(0);
	
	if(screen == NULL)
	{
		printf("Unable to set 0x0 video: %s\n", SDL_GetError());
		exit(1);
	}
	
	//Display menu
	Menu();

	//Initialize audio
	if (musicOn)
		InitAudio();
	
	InitDeck(screen, cardStyle);
	Klondike.Initialize(screen);

	//index 0
 	Klondike.CreateRegion(CRD_PILE, CRD_VISIBLE|CRD_3D, 0, 0, CRD_OSYMBOL, 15, 10, 2, 2);
	//index 1-7
	for(int i=1; i <= 7; i++)
	 	Klondike.CreateRegion(CRD_FOUNDATION, CRD_VISIBLE|CRD_DODRAG|CRD_DODROP, CRD_DOOPCOLOR|CRD_DOLOWER|CRD_DOLOWERBY1|CRD_DOKING, CRD_DRAGFACEUP, CRD_HSYMBOL, (CARDWIDTH * (i - 1)) + (i * 15), CARDHEIGHT + 40, 0, 11);
	//index 8
	if (!threeCards)
		Klondike.CreateRegion(CRD_RESERVE, CRD_VISIBLE|CRD_FACEUP|CRD_DODRAG|CRD_3D, CRD_DOALL, CRD_DRAGTOP, CRD_NSYMBOL, CARDWIDTH + 45, 10, 0, 0);
	else
		Klondike.CreateRegion(CRD_RESERVE,CRD_VISIBLE|CRD_FACEUP|CRD_DODRAG, CRD_DOALL,CRD_DRAGTOP,CRD_NSYMBOL, CARDWIDTH + 45, 10, 12, 0);
	//index 9-12
	for(int i=4; i <= 7; i++)
	 	Klondike.CreateRegion(CRD_WASTE, CRD_VISIBLE|CRD_3D|CRD_DODRAG|CRD_DODROP, CRD_DOSINGLE|CRD_DOHIGHER|CRD_DOHIGHERBY1|CRD_DOACE|CRD_DOSUIT, CRD_DRAGTOP, CRD_HSYMBOL, (CARDWIDTH * (i - 1)) + (i * 15), 10, 0, 0);
	//index 13 virtual region
	if (threeCards)
		Klondike.CreateRegion(CRD_VIRTUAL, CRD_DODRAG|CRD_DODROP,CRD_DOALL,CRD_DRAGSTACKS,CRD_NSYMBOL,CARDWIDTH + 45,0,0,0);
}

void NewGame()
{
	//Reset pile symbol
	Klondike[0].SetSymbol(CRD_OSYMBOL);

	//Empty the card regions from the previous game
	Klondike.EmptyStacks();

 	//create then shuffle the deck
	Klondike[0].NewDeck();
	Klondike[0].Shuffle();

	//deal
	for(int i=1; i <= 7; i++)
		Klondike[i].Push(Klondike[0].Pop(i));

    //initialize all card coordinates
    Klondike.InitAllCoords();

	//set initial faced up cards in foundations
	for(int i=1; i <= 7; i++)
		Klondike[i].SetCardFaceUp(true, Klondike[i].Size() - 1);
}

//  victory !!!
void Victory()
{
	AnimateCards(40);
	NewGame();
	Klondike.DrawStaticScene();
}
		
void HandleKeyDownEvent(SDL_Event &event)
{
	if(event.jbutton.button == GP2X_BUTTON_SELECT)		{ NewGame(); Klondike.DrawStaticScene(); }
	if(event.jbutton.button == GP2X_BUTTON_L)		{ AnimateCards(30); }; // Test animation
	if(event.jbutton.button == GP2X_BUTTON_R)		{ Klondike.DrawStaticScene(); }; // Refresh
	if(event.jbutton.button == GP2X_BUTTON_VOLDOWN) 
	{
		volume -= 20;
		if (volume < 0)
			volume = 0;
		Mix_VolumeMusic(volume);
	}
	if(event.jbutton.button == GP2X_BUTTON_VOLUP)
	{
		volume += 20;
		if (volume > 120)
			volume = 120;
		Mix_VolumeMusic(volume);
	}
}

bool startdrag = false;

//Button push
void HandleMouseDownEvent(SDL_Event &event)
{
	CCardRegion *srcReg;
	if(event.jbutton.button == GP2X_BUTTON_A)
	{
		srcReg = Klondike.OnMouseDown(x,y);
		if(srcReg == NULL) return;
		//clicked on the top of the foundations
		if((srcReg->Id == CRD_FOUNDATION) && srcReg->PtOnTop(x,y))
		{
			srcReg->SetCardFaceUp(true, srcReg->Size() - 1);
		}
		//clicked on the foundations, reserve, wastes for dragging
		if(((srcReg->Id == CRD_FOUNDATION) || (srcReg->Id == CRD_RESERVE) || (srcReg->Id == CRD_WASTE)) && Klondike.InitDrag(x,y))
		{
			startdrag = true;
			SDL_WM_GrabInput(SDL_GRAB_ON);
		}
		//clicked on the pile
		if(srcReg->Id == CRD_PILE)
		{
			CCardStack *cs = new CCardStack;
			
			if (!threeCards)
			{
				if(srcReg->Empty() && !Klondike[8].Empty() && turns > 0) //Bring back the cards
				{
					*cs = Klondike[8].Pop(Klondike[8].Size());
					cs->SetCardsFaceUp(false);
					Klondike.InitDrag(cs, -1, -1);
					Klondike.DoDrop(&Klondike[0]);
					Klondike[0].Reverse();
					Klondike[0].InitCardCoords();
					turns -= 1;
				}
				
				else if(!srcReg->Empty() && (!Klondike[8].Empty() || Klondike[8].Empty()))
				{
					*cs = Klondike[0].Pop(1);
					cs->SetCardsFaceUp(true);
					Klondike.InitDrag(cs, -1, -1);
					Klondike.DoDrop(&Klondike[8]);
				}
			}
			
			else
			{
				if(srcReg->Empty() && !Klondike[8].Empty() && turns > 0) //Bring back the cards
				{
					*cs = Klondike[8].Pop(Klondike[8].Size());
					cs->Reverse();
					cs->SetCardsFaceUp(false);
					Klondike.InitDrag(cs, -1, -1);
					Klondike.DoDrop(&Klondike[13]);
					*cs = Klondike[13].Pop(Klondike[13].Size());
					Klondike.InitDrag(cs, -1, -1);
					Klondike.DoDrop(&Klondike[0]);
					Klondike[0].Reverse();
					Klondike[0].InitCardCoords();
					turns -= 1;
				}
				
				else if(!srcReg->Empty() && (!Klondike[8].Empty() || Klondike[8].Empty()))
				{
					if(!Klondike[8].Empty())
					{	
						*cs = Klondike[8].Pop(Klondike[8].Size());
						cs->Reverse();
						cs->SetCardsFaceUp(false);
						Klondike.InitDrag(cs, -1, -1);
						Klondike.DoDrop(&Klondike[13]);
					}
					*cs = Klondike[0].Pop(3);
					cs->SetCardsFaceUp(true);
					Klondike.InitDrag(cs, -1, -1);
					Klondike.DoDrop(&Klondike[8]);
				}	
			}	
		}
	}

	//substitute right-click for double-click event
	if(event.jbutton.button == GP2X_BUTTON_B)
	{
		srcReg = Klondike.OnMouseDown(x,y);
		if(srcReg == NULL) return;
		CCardRegion *cr;
		CCard card =  srcReg->GetCard(srcReg->Size()-1);

		//clicked on the top of the foundations
		if(((srcReg->Id == CRD_FOUNDATION) || (srcReg->Id == CRD_RESERVE)) && card.FaceUp() && srcReg->PtOnTop(x,y))
		{
			if(cr = Klondike.FindDropRegion(CRD_WASTE, card))
			{
				CCardStack *cs = new CCardStack;
				*cs = srcReg->Pop(1);
				Klondike.InitDrag(cs, -1 , -1);
				Klondike.DoDrop(cr);
			}
		}
	}
}

//move joystick with the A button
void HandleMouseMoveEvent(SDL_Event &event)
{
	if(startdrag)
		Klondike.DoDrag(x,y);
}

//event when buttons are release
void HandleMouseUpEvent(SDL_Event &event)
{
	if (threeCards)
	{
		if (Klondike[8].Empty() && !Klondike[13].Empty())
		{
			CCardStack *cs = new CCardStack;
			
			*cs = Klondike[13].Pop(3);
			cs->SetCardsFaceUp(true);
			Klondike.InitDrag(cs, -1, -1);
			Klondike.DoDrop(&Klondike[8]);
		}
	}
	
	if((Klondike[0].Empty() && Klondike[8].Empty()) || (Klondike[0].Empty() && turns == 0))
	{
		Klondike[0].SetSymbol(1);
		Klondike.DrawStaticScene();
	}
	if((Klondike[9].Size() == 13) && (Klondike[10].Size() == 13) && (Klondike[11].Size() == 13) && (Klondike[12].Size() == 13))
		Victory();
}


int main(int argc, char *argv[])
{
	Initialize();
	NewGame();
	Klondike.DrawStaticScene();
	
	//Play music
	if (musicOn)
	{
		Mix_PlayMusic(music, -1);
		Mix_VolumeMusic(volume);
	}
	
	up=down=left=right=upleft=upright=downleft=downright=start=0;
	
	SDL_WarpMouse(x, y);
	SDL_ShowCursor (1);
	
	milliseconds=SDL_GetTicks();
	
	while(!start)
	{
		if (SDL_GetTicks()-milliseconds>SPF)
        {
			HandleInput();
			MoveCursor();
			milliseconds=SDL_GetTicks();
		}
	}

	// perform cleaning up
	SDL_JoystickClose(joystick);
	SDL_FreeSurface(screen);
	TTF_CloseFont(font);
	TTF_Quit();
	
	if (musicOn)
	{
		// Release the memory allocated to music
		Mix_FreeMusic(music);																		
		// Close SDL_Mixer Audio
		Mix_CloseAudio();
	}
	return 0;
}

void HandleInput()
{
    SDL_Event event;

    while(SDL_PollEvent(&event))
    {
        switch(event.type)
        {
            case SDL_JOYBUTTONDOWN: 
				HandleKeyDownEvent(event);
				HandleMouseDownEvent(event);
				KeyDown(event.jbutton.button); 
				break;
            case SDL_JOYBUTTONUP: 
				switch(event.jbutton.button)
            	{
                	case GP2X_BUTTON_A:
                    	if(startdrag)
						{	
							startdrag = false;
							Klondike.DoDrop();
							SDL_WM_GrabInput(SDL_GRAB_OFF);
						}
                      	HandleMouseUpEvent(event);
						break;
							
					case GP2X_BUTTON_B:
						HandleMouseUpEvent(event);
						break;
				}
				KeyUp(event.jbutton.button); 
				break;
        }
    }
	HandleMouseMoveEvent(event);
}

void KeyDown(const Uint8& key)
{
    switch(key)
    {
        case GP2X_BUTTON_START:     start=true; break;
        case GP2X_BUTTON_UP:        up=true; break;
        case GP2X_BUTTON_DOWN:      down=true; break;
        case GP2X_BUTTON_LEFT:      left=true; break;
        case GP2X_BUTTON_RIGHT:     right=true; break;
        case GP2X_BUTTON_UPLEFT:    upleft = true; break;
        case GP2X_BUTTON_UPRIGHT:   upright = true; break;
        case GP2X_BUTTON_DOWNLEFT:  downleft = true; break;
        case GP2X_BUTTON_DOWNRIGHT: downright = true; break;
        default: break;
    }
}

void KeyUp(const Uint8& key)
{
    switch(key)
    {
        case GP2X_BUTTON_START:     start=false; break;
        case GP2X_BUTTON_UP:        up=false; break;
        case GP2X_BUTTON_DOWN:      down=false; break;
        case GP2X_BUTTON_LEFT:      left=false; break;
        case GP2X_BUTTON_RIGHT:     right=false; break;
        case GP2X_BUTTON_UPLEFT:    upleft = false; break;
        case GP2X_BUTTON_UPRIGHT:   upright = false; break;
        case GP2X_BUTTON_DOWNLEFT:  downleft = false; break;
        case GP2X_BUTTON_DOWNRIGHT: downright = false; break;
        default: break;
    }
}

void MoveCursor()
{
	if (right || upright || downright) x++;
	if (left || upleft || downleft) x--;
	if (up || upleft || upright) y--;
	if (down || downleft || downright) y++;
	
	if (y>240) y = 1;
	if (x>320) x = 1;
	if (x<1) x = 320;
	if (y<1) y = 240;
	SDL_WarpMouse(x, y);
}

void DrawMenu(int pos,SDL_Surface *scr,SDL_Surface *img)
{
	SDL_FreeSurface(scr);
	SDL_BlitSurface(img,NULL, scr,NULL);
	
	if (pos == 0)
		drawText(screen,"New Game", 100, 100,sltmenu.r,sltmenu.g,sltmenu.b);
	else
		drawText(screen,"New Game", 100, 100,clrmenu.r,clrmenu.g,clrmenu.b);
	
	if (pos == 1)
		drawText(screen,"Options", 100, 140,sltmenu.r,sltmenu.g,sltmenu.b);
	else
		drawText(screen,"Options", 100, 140,clrmenu.r,clrmenu.g,clrmenu.b);
	
	if (pos == 2)
		drawText(screen,"Quit", 100, 180,sltmenu.r,sltmenu.g,sltmenu.b);   
	else
		drawText(screen,"Quit", 100, 180,clrmenu.r,clrmenu.g,clrmenu.b);  

	SDL_Flip(scr);
}	
	
void Menu()
{
	int position = 0;
	
	//Background...
	SDL_Surface *image;
	SDL_Surface *temp;

	temp = SDL_LoadBMP("gfx/menu_background.bmp");
	if (temp == NULL) 
	{
		printf("Unable to load bitmap: %s\n", SDL_GetError());
		exit(0);
	}
	image = SDL_DisplayFormat(temp);
	SDL_FreeSurface(temp);
	SDL_BlitSurface(image,NULL, screen,NULL);
	
	//Tittle
	LoadFont(40);
	drawText(screen, "Solitaire2x", 30, 26, clrFg.r, clrFg.g, clrFg.b);
	
	SDL_BlitSurface(screen,NULL, image,NULL);
	
	//Menu fonts
	LoadFont(20);
	DrawMenu(position,screen,image);
	
	//Joystick events
	SDL_Event event;
	
	bool play = false;
	while(!play)
	{
    	while (SDL_PollEvent(&event))
		{
			switch(event.type)
    		{
        		case SDL_JOYBUTTONDOWN:
            		switch(event.jbutton.button)
            		{
                 		case GP2X_BUTTON_DOWN:
                    		switch(position)
							{
								case 1: 
									position = 2;
									break;
							
								case 0:
									position = 1;
									break;
								
								default :
									position = 0;
									break;
							}
							DrawMenu(position,screen,image);
							break;
                	
						case GP2X_BUTTON_UP:
                    		switch(position)
							{
								case 1:
									position = 0;
									break;
							
								case 2:	
									position = 1;
									break;
								
								default:	
									position = 2;
									break;
							}
                      		DrawMenu(position,screen,image);
							break;
					
						case GP2X_BUTTON_A:
						case GP2X_BUTTON_CLICK:
							if (position == 0) play = true;
							if (position == 1) 
							{
								MenuOptions();
								DrawMenu(position,screen,image);
							}
							if (position == 2) exit(0);
							break;
					}			
            		break;
    		}
		}
    }			
}

void DrawMenuOptions(int pos,SDL_Surface *scr,SDL_Surface *img)
{
	SDL_Rect rcCard = {170,165,29,39};
	SDL_Rect rcCard2 = {205,165,30,39};
	
	SDL_Surface *card, *card2;
	SDL_Surface *temp, *temp2;

	switch (cardStyle)
	{
		case 0 :
			temp = SDL_LoadBMP("gfx/blue.bmp");
			temp2 = SDL_LoadBMP("gfx/blue2.bmp");
			break;
		case 1 :
			temp = SDL_LoadBMP("gfx/brown.bmp");
			temp2 = SDL_LoadBMP("gfx/brown2.bmp");
			break;
		default :
			temp = NULL;
			break;
	}
	
	if (temp == NULL) 
	{
		printf("Unable to load bitmap: %s\n", SDL_GetError());
		exit(0);
	}
	
	card = SDL_DisplayFormat(temp);
	card2 = SDL_DisplayFormat(temp2);
	SDL_FreeSurface(temp);
	SDL_FreeSurface(temp2);
	
	SDL_FreeSurface(scr);
	SDL_BlitSurface(img,NULL, scr,NULL);
		
	if (pos == 0)
		drawText(scr,"Distributed cards :",20,100,sltmenu.r,sltmenu.g,sltmenu.b);
	else
		drawText(scr,"Distributed cards :",20,100,clrmenu.r,clrmenu.g,clrmenu.b);
		
	if (pos == 1)
		drawText(scr,"Play music :", 20,120,sltmenu.r,sltmenu.g,sltmenu.b);
	else
		drawText(scr,"Play music :", 20,120,clrmenu.r,clrmenu.g,clrmenu.b);
	
	if (pos == 2)
		drawText(scr,"Number of turns :", 20, 140,sltmenu.r,sltmenu.g,sltmenu.b);
	else
		drawText(scr,"Number of turns :", 20, 140,clrmenu.r,clrmenu.g,clrmenu.b);
	
	if (pos == 3)
		drawText(scr,"Cards style :", 20, 160,sltmenu.r,sltmenu.g,sltmenu.b);
	else
		drawText(scr,"Cards style :", 20, 160,clrmenu.r,clrmenu.g,clrmenu.b);
	
	if (pos == 4)
		drawText(scr,"Return to menu", 20, 200,sltmenu.r,sltmenu.g,sltmenu.b);
	else
		drawText(scr,"Return to menu", 20, 200,clrmenu.r,clrmenu.g,clrmenu.b);
		

	if (threeCards)
		drawText(scr,"three", 250, 100, optmenu.r,optmenu.g,optmenu.b);
	else
		drawText(scr,"one", 250, 100, optmenu.r,optmenu.g,optmenu.b);

	if (musicOn)
		drawText(scr,"on", 190, 120, optmenu.r,optmenu.g,optmenu.b);
	else
		drawText(scr,"off", 190, 120, optmenu.r,optmenu.g,optmenu.b);
	
	drawTextInt(scr, turns, 245, 140, optmenu.r,optmenu.g,optmenu.b);
	
	SDL_BlitSurface(card,NULL, screen,&rcCard);
	SDL_BlitSurface(card2,NULL, screen,&rcCard2);
	
	SDL_Flip(scr);
}
	
void MenuOptions()
{	
	int position = 0;

	//Background...
	SDL_Surface *image;
	SDL_Surface *temp;

	temp = SDL_LoadBMP("gfx/options_background.bmp");
	if (temp == NULL) 
	{
		printf("Unable to load bitmap: %s\n", SDL_GetError());
		exit(0);
	}
	image = SDL_DisplayFormat(temp);
	SDL_FreeSurface(temp);
	SDL_BlitSurface(image,NULL, screen,NULL);
	
	//Tittle
	LoadFont(40);
	drawText(screen,"Options",68, 20, clrFg.r,clrFg.g,clrFg.b);
	
	SDL_BlitSurface(screen,NULL, image,NULL);
	
	//Menu items
	LoadFont(20);
	DrawMenuOptions(position,screen,image);
	
	//Joystick events
	SDL_Event event;
	bool returntomenu = false;

	while (!returntomenu)
	{
		while (SDL_PollEvent(&event))
		{
			switch(event.type)
    		{
        		case SDL_JOYBUTTONDOWN:
            		switch(event.jbutton.button)
            		{
                 		case GP2X_BUTTON_DOWN:
                    		switch(position)
							{
								case 3:
									position = 4;
									break;
								
								case 2:
									position = 3;
									break;
								
								case 1:
									position = 2;
									break;
								
								case 0:
									position = 1;
									break;
								
								default:
									position = 0;
									break;
							}
							DrawMenuOptions(position,screen,image);
							break;
							
						case GP2X_BUTTON_UP:
							switch(position)
							{
								case 1:
									position = 0;
									break;
								
								case 2:
									position = 1;
									break;
								
								case 3:
									position = 2;
									break;
								
								case 4:
									position = 3;
									break;
								
								default:
									position = 4;
									break;
							}
							DrawMenuOptions(position,screen,image);
							break;
							
						case GP2X_BUTTON_RIGHT:
							switch (position)
							{
								case 0: 
									threeCards = true;	
									break;
								
								case 1:
									musicOn = true;
									break;
								
								case 2:
									turns += 1;
									if (turns > 100)
										turns = 100;
									break;
								
								case 3:
									cardStyle = 1;
									break;
							}								
							DrawMenuOptions(position,screen,image);
							break;
						
						case GP2X_BUTTON_A:
						case GP2X_BUTTON_CLICK:
							if (position == 4)
							returntomenu = true;
							break;	
						
						case GP2X_BUTTON_LEFT:
							switch (position)
							{
								case 0: 
									threeCards = false;	
									break;
								
								case 1:
									musicOn = false;
									break;
								
								case 2:
									turns -= 1;
									if (turns < 0)
										turns = 0;
									break;
								
								case 3:
									cardStyle = 0;
									break;
							}								
							DrawMenuOptions(position,screen,image);
							break;
						}
						break;
			}
		}		
	}
}

//Initialize audio
void InitAudio()
{
	if(Mix_OpenAudio(MIX_DEFAULT_FREQUENCY, AUDIO_S16, MIX_DEFAULT_CHANNELS, 512) < 0) 
	{
       printf("Unable to open audio!\n");
       exit(1);
 	}
	
	volume = 60;
	
	music = Mix_LoadMUS("gfx/music.ogg");
	if(music == NULL) 
	{
		printf("Unable to load Ogg file: %s\n", Mix_GetError());
		exit(0);
	}
}

//Load font...
void LoadFont(u8 size)
{
	font = TTF_OpenFont("gfx/font.ttf", size);
}

//Draw text on screen
void drawText(SDL_Surface* scr, char* string, int x, int y, int fR, int fG, int fB)
{
	SDL_Color foregroundColor = { fR, fG, fB };
	SDL_Surface* textSurface =  TTF_RenderText_Blended(font,string, foregroundColor);
	SDL_Rect textLocation = { x, y, 0, 0 };
	SDL_BlitSurface(textSurface, NULL, scr, &textLocation);
	SDL_FreeSurface(textSurface);
}

//Draw number on screen
void drawTextInt(SDL_Surface* screen, int number, int x, int y, int fR, int fG, int fB)
{
	char tmp_num[16];
	sprintf((char*)tmp_num, "%d", number);
	SDL_Color foregroundColor = { fR, fG, fB };
	SDL_Surface* textSurface =  TTF_RenderText_Blended(font,tmp_num, foregroundColor);
	SDL_Rect textLocation = { x, y, 0, 0 };
	SDL_BlitSurface(textSurface, NULL, screen, &textLocation);
	SDL_FreeSurface(textSurface);
}
